<?php

namespace AustraliaPost\Extensions\Business\Outage;

class Outage_Alerts {

    const API_URL = 'https://mypost-forwarder.wpruby.com/api/planned-outages';

	/**
	 * The single instance of the class.
	 *
	 * @var Outage_Alerts
	 */
	protected static $_instance = null;

	/**
	 * @return Outage_Alerts
	 */
	public static function get_instance()
	{
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	public function __construct()
	{
		add_action( 'admin_notices', [$this, 'display_outage_alerts' ]);
	}

	public function display_outage_alerts()
	{
	    foreach ($this->get_notices() as $notice) {
		    ?>
            <div class="notice notice-warning is-dismissible">
                <p><strong>Australia Post Planned Outage Notice</strong></p>
                <p><?php echo $notice ?></p>
            </div>
		    <?php
        }
	}

	private function get_notices()
	{
	    $notices = get_transient('_planned_outage_notices');

	    if ($notices !== false) {
	        return $notices;
	    }

	    $response = wp_remote_get(self::API_URL, ['timeout' => 1]);

	    if ($response instanceof \WP_Error) {
	        return [];
	    }

	    if (!isset($response['body'])) {
            return [];
	    }

	    $response = json_decode($response['body'], true);

		if (!isset($response['notices'])) {
			return [];
		}

		set_transient('_planned_outage_notices', $response['notices'], 43200); // 12 hours

		return $response['notices'];

	}

}
